"""Setup for the cs.eyrie package."""

import setuptools
import os


setuptools.setup(
    author="sihish",
    author_email="hace@gmail.com",
    name='zeev_test2',
    license="MIT",
    description='cs.eyrie is a amazing package for data handling',
    version='v0.9.0',
    long_description="no long decsription given",
    url='https://github.com/aaaditisinghhhh/',
    packages=setuptools.find_packages(),
    python_requires=">=3.5",
    classifiers=[
        # Trove classifiers
        # (https://pypi.python.org/pypi?%3Aaction=list_classifiers)
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Intended Audience :: Developers',
    ],
)
